pydevDAG._readwrite._utils module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »

# pydevDAG._readwrite._utils module

## pydevDAG._readwrite._utils

Utilities for reading and writing.

class `pydevDAG._readwrite._utils.` `StringUtils`

  Bases: `object`

  String related utilities.

  static `as_string`(graph, write_func)

    Return the entire graph as a single string in a structured format.

    Parameters: | graph (DiGraph) – the graph write_func (DiGraph * file -> NoneType) – the function to write the graph
    Returns: | the graph as a stringlike thing

  static `from_string`(instr, read_func)

    Get a graph from a string.

    Parameters: | read_func – a function that reads data from an input stream

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »